Handbook - Muscle System Somatic Muscle
Description: WormAtlas: A database of behavioral and structural anatomy of Caenorhabditis elegans.
Keywords: Caenorhabditis, elegans, anatomy, hermaphrodite, worm, nematode

Home Handbooks Hermaphrodite Male Dauer Embryo Aging P. pacificus S. stercoralis Resources WormImage Slidable Worm WormWiring Hall Lab Anatomical Methods Glossary of Terms Movie Gallery Individual Neurons Neurons & Circuits Worm Literature Cell Identification Cell Lineages Cell List Sperm Gallery Digital Development DIC PharynxAtlas User Guides Abbreviations Color Codes Copyright and Use How to Cite Links WormBase WormBook CGC WormGUIDES CytoSHOW OpenWorm Nemanode CeNGEN C. elegans Natural Diversity Anatomy by DIC - by J. Yochem About Us Mission Statement Contact

MUSCLE SYSTEM SOMATIC MUSCLE Click pictures for new window with figure and legend, click again for high resolution image
1 Nematode Somatic Muscle In C. elegans, the 95 rhomboid-shaped body wall muscle cells are arranged as staggered pairs in four longitudinal bundles located in four quadrants (MusFIG 7). Three of these bundles (DL, DR, VR) contain 24 cells each, whereas the VL bundle contains 23 cells. This asymmetry appears to result from a gap on the ventral left quadrant of the embryo, slightly posterior to the gonad primordium (Sulston and Horvitz, 1977). Muscles are always separated from the underlying hypodermis and nervous tissue by a thin (approximately 20 nm) basal lamina (BL). This BL remains intact within the synaptic regions, except for NMJs made in the nerve ring between the RIML/R motor neurons and their target muscle arms. A typical somatic muscle cell has three parts: the contractile filament lattice (spindle), a noncontractile body (muscle belly) containing the nucleus and the cytoplasm with mitochondria, and the muscle arms, slender processes that extend to either ventral or dorsal nerve cords or the nerve ring (MusFIG 8) (see Introduction to Muscle). Somatic muscle nuclei are oblong (ovoid), intermediate in size between neuronal and hypodermal nuclei, and have a small, spherical nucleolus. Viewed by differential interference contrast (DIC) microscopy, their nucleoplasm appears granular in L1, but becomes smooth in L2 and remains so throughout the rest of the development (Sulston and Horvitz, 1977). MusFIG 7: Head, neck and body wall muscles. A-D. Epifluorescent images from transgenic animals expressing the unc27::GFP reporter gene. Muscle cells are numbered according to Hedgecock et al., 1987. (Strain source: L. Jia and S.W. Emmons.) A. The organization of somatic muscles in the adult C. elegans hermaphrodite, dorsal oblique view. The body wall muscles are organized in four quadrants (only the dorsal quadrants are visible) with two rows of cells in each. The quadrants are placed subdorsally and subventrally. The two dorsal quadrants flank the dorsal hypodermal ridge and the dorsal cord, and the ventral quadrants flank the ventral hypodermal ridge and the ventral nerve cord. Anteriorly, the spindle-shaped cells in each quadrant are arranged almost in pairs, whereas more posteriorly the cells are organized in an alternating fashion. As a result of this arrangement, two thirds of all somatic muscle cells are located anterior to the vulva. For most cells, the muscle nucleus is centered along the anterior-posterior axis with respect to its spindle-shaped collection of sarcomeres. At the tail tip, the last muscle cell in the left dorsal quadrant continues further posteriorly in a more medial position, whereas the right dorsal quadrant terminates (not shown). Bar, 50 µm. B. Arrangement of head and neck muscles, ventral view. The first muscle cells that are close to the midline in each quadrant are smaller than their counterparts (compare muscle cell 1 to muscle cell 2). (Green dotted lines) Positions of the anterior and posterior bulbs of the pharynx; (blue dotted line) ventral midline. A-C correspond to the first three blocks of head muscles in quadrants. Original magnification, 600x. C. Arrangement of the somatic tail muscles, ventral view. Original magnification, 600x. D. Arrangement of body wall muscles near the vulva, ventral view. Bar, 50 µm. E. Differential interference contrast (DIC) image of the posterior head in an adult animal, lateral view. Neck muscle nuclei (arrows) in the dorsal and ventral left muscle quadrants are arranged as tandem pairs. (Left inset) One of the nuclei as magnified. Smooth nucleoplasm and nucleolus (white arrow) are easily visible. F. DIC image. Same animal as in E, but with more lateral focal plane. The boundaries of muscle cell spindles and muscle nuclei (colored with green lines) are visible. The cell bodies are arranged in tandem, similar to the nuclei. Because the nuclei lie in the more medial portions (muscle belly) of the muscle cells where the muscles are wider, the nuclei positions look somewhat skewed in this image with respect to the superficial sarcoplasmic portions. Bar, 10 µm. 2 Structure of Somatic Muscle The body wall muscle of C. elegans, as in all other nematodes, is obliquely striated (MusFIG 8). Although the filaments themselves are oriented parallel to the longitudinal axis of the muscle cell, adjacent structural units (M lines and DBs) are offset from one another by more than a micron, rather than being in register as in vertebrate cross-striated muscle (Waterston, 1988; Bird and Bird, 1991). Therefore, the observed A–I striations occur at an angle of 5–7° with respect to the longitudinal axes of the filaments and the muscle cell, in comparison to 90° in vertebrate cross-striated muscle (MusFIG 9 and MusTABLE 1). This oblique arrangement of the sarcomeres is suggested to create a more evenly distributed muscle force application over the BL and cuticle, allowing for smooth bending of the body rather than kinking (Burr and Gans, 1998). Each somatic muscle cell is attached basally to the underlying hypodermis and cuticle and laterally to the neighboring muscle cells through three distinct PAT-2/PAT-3 integrin-containing attachment complexes. These include DBs, M lines, and lateral attachment plaques. MusFIG 8: Structure of the platymyarian obliquely striated muscle. A. Schematic diagram of a body wall muscle cell. Rows of dense bodies (dots) and A bands (thin lines) give the striated appearance macroscopically. Attachment plaques are localized at the end of the terminal half I bands, where the muscle cells in a quadrant contact one another. (Top inset) Layers of tissue from outside (cuticle, top) to inside (muscle, bottom). (Bl) Basal lamina between muscle and hypodermis (Hyp). B. Schematic diagram of a wedge of the myofibrillar portion and the muscle belly. The nucleus and the organelles are located within the muscle belly. The myofilament lattice is arranged as a sheet of filaments on the side of the muscle cell that apposes the hypodermis. Contractile units are in register longitudinally; however, they are placed in tandem horizontally, giving rise to an alternating pattern of thick (small yellow dots and lines) and thin filaments (small black dots and lines) bands. The thin filaments are omitted from the lateral and top sides of the drawing. (DB) Dense body.
MusFIG 9: Organization of the myofilament lattice. (Yellow lines) Thick filaments; (black lines) thin filaments; (black dots) DB; (brown dots) M lines. A. Three-dimensional rendering of myofilament lattice as well as structure of the sarcomere. B. Schematic illustration of a cross section of the myofilament lattice. In the muscle cell, the sheet of filaments lies inside the muscle membrane, which is separated from the underlying hypodermis by a 20-nm basal lamina (BL). Cuticle, in turn, lies outside the hypodermis (Hyp). The striations created by the thick and thin filaments are at an angle of 5-7°to the longitudinal axes of the filaments and the muscle cell (shown at an increased angle for emphasis; compare to C). C. Accurate surface view of myofilament structure and filament packing. Note that the distance between DBs (black dots) on the longitudinal axis is more than 10 µm (y), whereas in the tranverse plane they are only about 1 µm apart (x), for a ratio of about 10:1 (R.H. Waterston, pers. comm.). D. The surface view is laterally extended to better indicate the offset of contractile units (offset is increased for emphasis; compare with C). E. Comparison of packing of thick (yellow dots) and thin (black dots) filaments at transverse section among the vertebrate skeletal muscle, the insect flight muscle, and the nematode body wall muscle.
MusTABLE 1: Differences between C. elegans and vertebrate striated muscle. Based on Zengel and Epstein, 1980; Waterston, 1988; Bird and Bird, 1991; Moerman and Fire, 1997. 2.1 Basal Attachments In C. elegans, the myofilament lattice of each contractile unit is anchored to the muscle cell membrane and adjacent BL by DB and M lines, which are highly ordered, regularly spaced structures that extend from the cytoplasm to the plasma membrane (MusFIG 10). DB and M lines are homologous to vertebrate focal adhesion plaques and contain many of the cytoskeletal adaptor proteins of these integrin-mediated attachments, including talin, PAT-6/actopaxin, PAT-4/ILK, and UNC-97/PINCH. DBs also share some components with muscle–muscle attachment plaques (Francis and Waterston, 1985). MusFIG 10: Structure of the C. elegans body wall muscle cell. A. Low- power TEM showing the relationship of the muscle quadrants to the hypodermis and internal organs, transverse section. Bar, 1 µm. (Image source: [Hall] N501-N354.) B. Sarcomeres in a higher-magnification TEM, transverse section. Each adult hermaphrodite muscle cell may grow to be as wide as 10 sarcomeres, which are the repeating contractile units underneath the muscle cell plasma membrane facing the hypodermis (Hyp). Mitochondria cluster at the boundary of the myofilament lattice and the muscle belly. The muscle belly also contains the nucleus and other organelles. Bar, 1 µm. (Image source: [Hall] N501C.) C. Cross section of a single sarcomere. Same image as in B, magnified. Parts of two DBs are seen at the ends of half I (thin filament) bands on each side. A thin M line is seen to occupy the middle of the A (thick filament) band. The membranous sacs of sarcoplasmic reticulum (SR) align around the dense body and are also present under the thick and thin filament bands along the muscle membrane (top right inset). The arrangements of thick and thin filaments are shown in the top insets on the left, as both magnified TEM images and schematic drawings. Muscle cell is separated from the hypodermis and cuticle by the basal lamina (orange layer). Bar, 0.5 µm. At the plasma membrane, DB and M lines are mechanically linked to the outside cuticle through BL components and hypodermal fibrous organelles (FOs) (MusFIG 11 and MusFIG 12) (Waterston, 1988; Francis and Waterston, 1991; Moerman and Fire, 1997; Coutu Hresko et al., 1999; Hahn and Labouesse, 2001; Cox and Hardin, 2004). Perlecan and collagen IV concentrate in the BL underneath each DB and M line, which align with FOs of the hypodermis. FOs are also known as transepidermal attachments and are homologous to vertebrate hemidesmosomes (HD) that anchor the intermediate filament network to the plasma membrane and BL (Ding et al., 2004; Labouesse, 2006). Like HD, they are seen as two electron-dense plaques, one on the inside of each hypodermal plasma membrane, which are connected by cytoplasmic intermediate filaments that span the width of the hypodermis (MusFIG 11). FOs are restricted to the thin hypodermal regions that overlie muscle cells, and they form concurrently with muscle development. In early embryonic stages, they are localized into longitudinal strips; however, during elongation of the embryo and as circumferential actin bundles form in hypodermal cells, they change into a circumferential stripe pattern. This pattern continues through larval and adult stages (Ding et al., 2004). MusFIG 11: Structure and components of C. elegans fibrous organelles (FOs). A. Graphic rendition of a section through the body with the cuticle (gray) and the hypodermis (beige) peeled off from the dorsal left quadrant to expose fibrous organelles (small dots), attachment plaques (large oval dots), and the underlying muscle (green). FOs are oriented circumferentially over the muscle cells, orthogonal to the anterior-posterior orientation of the myofilaments. (Orange layer) Basal lamina. B. Components of DB and M lines. Many of the proteins found in DBs, M lines, and attachment plaques are similar to those seen in vertebrate focal adhesions. C. Schematic illustration of the muscle-hypodermis-cuticle anchorage structures that allow mechanical force to be transmitted across the muscle cell membrane to the cuticle (Labouesse, 2006). FOs correspond to the structures formed by hemidesmosome-like electron-dense plaques found on either side of the hypodermal plasma membranes, with interconnecting intermediate filaments (IFs). On the muscle side, the transmembrane extracellular matrix receptor PAT-2/PAT-3 integrin and the basement membrane protein UNC-52/perlecan are concentrated at the sites around the DB and M lines. On the hypodermal side, homologous transmembrane proteins MUA-3 and MUP-4 may be localized at the apical hypodermal surface and bind to intermediate filaments within the hypodermis and collagens in the outside cuticle. D. FOs are localized in circumferentially oriented bands over the muscle quadrants. FOs are shown by GFP labeling of intermediate filaments in the hypodermis of a transgenic animal expressing the mua6::GFP reporter gene. Epifluorescent image, left lateral view. (Strain source: V. Hapiak and J. Plenefisch. Image source: R. Lints.). E. Longitudinal TEM thin section showing hemidesmosomes on both sides of the hypodermis. (Image source: [Hall] fat-3 T411.) MusFIG 12: Surface views of obliquely striated somatic muscles of C. elegans. All images are from a transgenic adult animal expressing the unc27::GFP reporter gene. Bar, 10 µm. (Strain source: L. Jia and S.W. Emmons.) A. Dorsal view of two staggered spindle-shaped cells (one is partly out of the plane of focus) from a single quadrant. Epifluorescent image. I bands are labeled with the troponin-GFP marker, and each I band appears as a pair of longitudinal white lines. A bands (thick filaments) are not labeled and their territories appear dark. The border between the two muscle cells is demarcated by a disruption in the linear pattern. B. The same plane of focus as in A (DIC image). DBs (arrowheads) are visible as rows of small bumps organized in the same orientation as the myofilaments. M lines, which occupy the middle of A bands, are smaller and not clearly visible. C. Overlay of the images in A and B. DBs occupy the middle of the I bands. Loss of function in components of DB and M lines frequently results in detachment of body wall muscles from the cuticle, supporting the hypothesis that these attachment structures function to promote mechanical strength between the muscle and hypodermis (Gatewood and Bucher, 1997; Plenefisch et al., 2000). 2.2 Attachment Plaques (Lateral Attachments) Similar to myotendinous junctions of vertebrate skeletal muscle, the ends of C. elegans somatic muscle cells contain thin (actin) filament attachment plaques (the ends of the terminal half I bands at which microfilaments are attached to the cytoplasmic surface of the plasma membrane), which are most similar to DBs (MusFIG 13). By means of attachment plaques, each of the muscle cells adheres tightly to adjacent muscle cells within one quadrant (Francis and Waterston, 1991; Coutu Hresko et al., 1994). Although this may allow for some tension to be transmitted longitudinally between cells, the bulk of the tension created by muscle contraction is transferred to the exoskeleton/cuticle through basal attachments that are distributed along the entire length of the cell (Francis and Waterston, 1985; Woo et al., 2004). MusFIG 13: Structure of attachment plaques. A. Attachment plaques are localized at the end of half I bands (thin filaments), where two muscle cells appose each other (green dotted lines indicate muscle cell membranes). Ultrastructurally, attachment plaques resemble DBs as electron-dense finger-like structures, and they also share some of the protein components of DBs. TEM, transverse section. Bar, 0.5 µm. (Image source: N2Y [MRC] 689-2/794L.) B. Schematic illustration of localization of attachment plaques between the muscle cells of the dorsal left somatic muscle quadrant. C. Placement of attachment plaques between two rows of a muscle quadrant. I bands are seen as light, longitudinal bands within each cell. Plaques are pseudocolored over an epifluorescent image taken from a transgenic animal expressing the unc-27::GFP reporter gene. Attachment plaques relay some tension longitudinally between cells (force b), but the major force generated by muscle contraction is transferred to the cuticle through basal attachments and FOs that are distributed along the entire length of the cell (force a, which acts orthogonally to this focal plane). 3 Development of Somatic Muscle The body wall muscle cells are derived from D, C, AB, and MS cell lineages. At hatching, 81 of the 95 cells are present. Fourteen more muscle cells are generated post-embryonically from the MSapaapp lineage (MusFIG 14 , MusFIG 15A and MusFIG 15B) (Sulston and Horvitz, 1977; Sulston et al., 1983). Of the 81 body muscles of the newly hatched larva, 80 are generated in symmetrical fashion from MS, C, and D lineages. Twenty come from the D blast cell, which generates body muscle cells exclusively, 16 from Cp, 16 from Ca, 9 from MSpp, 6 from MSpa, 9 from MSap, and 4 from MSaa (Sulston et al., 1983). The remaining cell is generated by ABprpppppa and is one of a group of four muscles generated preanally by ABp(l/r)pppppa lineages (the other three cells become the anal depressor muscle, the sphincter muscle, and one of the two stomatointestinal muscles). MusFIG 14A-E: Development of somatic muscle. A. A 290-minute embryo after first cell cleavage. Myoblasts arise after the end of gastrulation and are localized adjacent to seam cells. They have started to accumulate structural components such as myosin, actin, vinculin, and integrin (small speckles inside myoblasts). Early myoblasts are almost spherical. The dorsal and ventral hypodermis contain some hemidesmosome components (dotted areas within the beige circle). Dorsal hypodermal cells have not yet intercalated. B. A 350-minute embryo. Starting at the anterior end, muscle cells have migrated to form the ventral and dorsal muscle quadrants between 300 and 350 minutes and have reached their final positions. All muscle cells have gone through their final divisions. Muscle cells are still round but have become polarized; myofibrillar components (colored dots within muscle cells) are clustered where the two muscle cells appose each other and the hypodermis. C. A 420-minute embryo. Muscle cells have flattened basally against the hypodermis and laterally against their muscle neighbors. Myofibrillar components, basal lamina, and hypodermal hemidesmosome components have aligned. D. A 450-minute embryo, midembryogenesis. Muscle-muscle and muscle-hypodermis junctions and sarcomeres organize to provide a physical linkage between cells. All types of attachments (DB, M lines, attachment plaques) appear morphologically similar to electron-dense plaques when they are first formed (Coutu Hresko et al., 1994; Moerman and Williams, 2006). In larval stages, DBs and M lines acquire their finger-like shapes by extending deeper into the cytoplasm. E. Schematic drawing of localization of embryonic somatic muscle cells (green) with respect to the hypodermis (beige) and seam blast cells (dark orange) in a filleted embryo. At the stage shown, the dorsal hypodermal cells have completed their intercalation and are organized in a single dorsal row. (a) Anus; (d) anterior deirid; (dm) dorsal midline; (e) excretory pore; (vm) ventral midline. Only the right-side seam blast cells and P cells are labeled. Hypodermal cells are unlabeled and the anterior hypodermis is omitted. (Based on Hedgecock et al., 1987.) MusFIG 14F-K: Development of somatic muscle. F-I. Developing muscles in embryos stained with the muscle marker NE8 4C6.3, left lateral view. Bar, 10 μm. (Reprinted, with permission, from Moerman et al., 1996. ©Elsevier.) F. Approximately 310-minute embryo after first cell cleavage. Muscle cells start to migrate from a lateral position adjacent to seam cells to ventral and dorsal sides. The anterior part has separated, whereas the posterior half is still in a continuous sheet. G. Approximately 330-minute embryo. The more posterior muscle cells also started to move dorsally and ventrally. H. Approximately 350-minute embryo. Dorsal and ventral muscle quadrants have formed. I. A 420-minute embryo (1.5-fold stage). Muscle cells become more flattened as myofilaments are forming. J. Location of body wall muscle cells (green lines) in strips in the dorsal and ventral quadrants in a 1.75-fold (420-450 min) embryo just after acquisition of contractile function (compare to MusFIG 15), left lateral view. Arrangement of A bands is shown inside three muscle cells. There are four A bands across the quadrant because each muscle cell is only two sarcomeres wide. The position of the deirid (d) is also shown for relative position. (Based on Williams and Waterston, 1994; Moerman and Fire, 1997.) K. Illustration of the relative positions of 40 body wall muscle nuclei on the left side of the embryo. (Based on Sulston et al., 1983.) MusFIG 15A: Arrangement of body wall muscle cells in the adult hermaphrodite. The animal is filleted along the dorsal midline. Lineal origins of the muscle cells are indicated. Each quadrant contains 24 mononucleate diploid cells, except for the ventral left quadrant, which contains 23 cells. Red lines separate the head, neck and body muscle, which receive distinct innervations from motor neurons. The 16 head muscle cells (A and B blocks) in eight rows receive innervation exclusively from the nerve ring motor neurons and motor neurons of the ventral cord, whereas body muscles receive innervation only from ventral nerve cord motor neurons. (Solid green cells) Post-embryonic additions to the muscle quadrants. (dm) Dorsal midline; (vm) ventral midline. (Based on Sulston and Horvitz, 1977; Sulston et al., 1983; Moerman and Fire, 1997. Muscle cells are numbered according to Hedgecock et al., 1987 which differs from Wormbase) MusFIG 15B: Arrangement of body wall muscle cells in the embryo at 430 min after first cell division. Numbers in red indicate times of cell births. (Based on Sulston et al., 1983.) Note, MSpappal is shown as MSpappaa in the lineage diagram and MSpappar is shown as MSpappap (R. Lee pers. comm., and Richards et al., 2013.) Myoblasts are born after the end of gastrulation at about 290 minutes of embryonic development (MusFIG 14 and MusTABLE 2). At this stage, muscle cells lie in two lateral rows next to the seam cells, and some muscle cells have not yet undergone their terminal divisions. During this time, hemidesmosome components start to accumulate in the hypodermis in a diffuse fashion and muscle cells start accumulating muscle components diffusely. Subsequently, at about 350 minutes of development, the muscle cells migrate dorsally and ventrally to contact the ventral and dorsal hypodermis (Coutu Hresko et al., 1994; 1999). All muscle cells finish their divisions before assuming their final positions. Cell–cell contact induces the components of the muscle contractile apparatus to coalesce at the membrane near the contact points, and fibrous organelle components (MH5 protein, intermediate filaments) become restricted to specific regions of the hypodermis adjacent to muscle. BL components are initially recruited to regions of contact between muscle cells. Hypodermal myotactin then accumulates adjacent to where the contractile apparatus is forming in the muscle. By the twofold stage of development, muscle cells become flattened and muscle attachment and myofilament lattice assembly begins, following positional cues laid down in the BL and muscle cell membrane (Coutu Hresko et al., 1994; Williams and Waterston, 1994; Moerman and Williams, 2006). UNC-52/perlecan in BL initiates and is essential in the assembly of both DB and M-line components. In mutants that lack UNC-52, all subsequent steps of sarcomere development are blocked. Then, integrin heterodimers polarize to the basal membrane of the muscle and aggregate into a series of organized focal contacts in each muscle quadrant, in correspondence with the UNC-52 sites. Next, other components of the attachment complexes, such as PAT-4/ILK and PAT-6/ actopaxin, are recruited to these focal contacts. Recruitment of ILK initiates divergence into distinct actin and myosin filament anchorage sites as the DB and M lines, respectively (Moerman and Williams, 2006). In the final step, actin and myosin filaments are recruited to these proto-DB and M-line complexes, respectively, at the basal plasma membrane. As the contacts mature, they form the highly ordered, recognizable series of DB and M lines. Sarcomeres then become organized into oblique striations, and the interlocking arrangement of the rhomboid-shaped body wall muscle cells in separate bundles becomes apparent. At the earliest stage at which individual muscle cells become discernable, each cell is two A bands wide and the filaments are about 5 μm long (Moerman and Fire, 1997). During this time, myotactin remains adjacent to the forming contractile apparatus, and its organization follows the oblique striations of the muscle. In contrast, components of fibrous organelles become organized in circumferentially oriented bands restricted to regions where hypodermis is adjacent to muscle. By the threefold stage (520 min after first cleavage of the embryo at 25°C), myotactin is seen to colocalize with fibrous organelle components in these bands (Coutu Hresko et al., 1999). Muscle cell mass increases at each larval stage such that in the adult, each muscle cell may have grown to be as wide as 10 A bands and becomes approximately 100 μm long. Individual filaments in the adult are 10 μm long, and DB and M lines have also increased in size with larger integrin clusters (Moerman and Williams, 2006). MusTABLE 2: Embryonic events in muscle and body wall development at 25°C. The zero time point is first cell cleavage (based on Sulston et al., 1983; Coutu Hresko et al., 1994; Rogalski et al., 2001). During their formation in the embryos, all three types of attachment complexes look similar as electron-dense plaques. It is only during postembryonic larval stages that DB and M lines acquire their finger-like shapes by projecting into the cytoplasm from the plasma membrane. For DB, this projection coincides with the addition of α-actinin into the structure more distal from the membrane (Francis and Waterston, 1985; Barstead and Waterston, 1991; Moerman and Williams, 2006). Mutants with severe defects in sarcomere assembly become paralyzed with arrested elongation at the twofold stage (pat phenotype) of embryogenesis and fail to display any flipping motions (Williams and Waterston, 1994). 4 Muscle Basal Lamina (Basement Membrane) As in other organisms, BL are thin sheets of specialized extracellular matrices that contain type IV collagen, laminin, nidogen, SPARC, and perlecan in C. elegans. Somatic muscle quadrants in the body run inside tubes of BL, which separates them from the pseudocoelomic cavity and underlying hypodermis and nervous tissue. The neuronal processes that run from the ventral side to the dorsal side (commissures) extend under this BL and between muscle and hypodermis. In the head, the BL is extended around the muscle arm plate and separates the muscle arms from the nerve ring. This extension of BL terminates onto the cylinder of sheet-like processes of the GLR cells, anterior to the nerve ring (White et al., 1986). 5 Innervation of Somatic Muscle Depending on the basis of their synaptic input, somatic muscles fall into three groups: (1) The anteriormost four somatic muscle cells in each quadrant (head muscles) are innervated by motor neurons in the nerve ring, (2) the next four cells in each quadrant (neck muscles) receive dual innervation from motor neurons of the nerve ring and the ventral nerve cord, and (3) the remainder (body muscles) are exclusively innervated by ventral cord motor neurons (White et al., 1986; Bird and Bird, 1991). Such innervation involves chemical synapses (NMJs) at the muscle plate. The muscle cells in each row of a muscle quadrant are electrically coupled to their neighbors through gap junctions, most often occurring between the muscle arms. Also, the muscle arms from the neck muscles make extensive gap junctions with the head mesodermal cell, which may provide electrical coupling between the dorsal and ventral muscles in this region (White, 1988). (For detailed description see Gap Junctions).
> 5.1 Body Body muscles are innervated by the cholinergic, stimulatory A- and B-type motor neurons (VA, VB, DA, DB, AS) and inhibitory, γ-aminobutyric acid-transmitting (GABAergic) D-type motor neurons (VD, DD) of the ventral nerve cord. (For a detailed description of innervation of body muscles, see Nervous System) They may also receive modulatory inputs from neuron processes in the sublateral cords (J.S. Duerr et al., unpubl.). 5.2 Head and Neck Although the body is limited to making dorsoventral bends, the nematode’s head is capable of lateral motions as well. These more refined motions are believed to be due to more complex wiring of the head and neck muscles at the nerve ring, permitting differential activation of muscles in adjacent bands and even in adjacent rows in one quadrant (White et al., 1986). Head motor neuron classes include fourfold symmetric RME, SMB, and URA neurons; sixfold symmetric IL1 neurons; and bilaterally symmetric RIM, RMF, RMG, RMH, and RIV neurons (White et al., 1986). RMD and SMD motor neurons are suggested to be the cross inhibitors in the nerve ring, although the pattern of cross-inhibition is probably more complex in the head compared to the body. Both classes of putative cross-inhibitory motor neurons receive extensive synaptic input from interneurons, unlike D-type body neurons, which are only post-synaptic to ventral cord motor neurons at NMJs. The major source of synaptic input to RMD and SMD neurons comes from RIA interneurons, which themselves receive prominent input from RIB interneurons. RME neurons have been shown to limit the extent of head deflection during foraging, because head movements during foraging become loopy when RMEs are ablated (MusFIG 16) (McIntire et al., 1993; Jorgensen, 2005). RMEs are post-synaptic to stretch-receptive SMBs, and they make inhibitory NMJs onto the contralateral anterior head muscles that may have a role in restricting the level of contraction of the ventral or dorsal group of muscles during head bending (Jorgensen, 2005). MusFIG 16: Innervation of head muscles for foraging. The long, synapse-free processes of SAA and SMB may become activated by the head curving when ventral muscles contract (only SMBD, which makes chemical synapses onto dorsal head muscles, and SAAD are shown). These may in turn activate the GABAergic and inhibitory RME neurons, which would relax the contracted muscles on the ventral side. Mutant animals that lack GABAergic transmission have exaggerated, loopy head movements. RMEs also receive input from mechanosensory IL1, IL2, OLQ, and OLL neurons. (Arrows) Chemical synapses; (T bars) inhibitory, GABAergic transmission; (double bars) gap junctions. (Based on White et al., 1986; Jorgensen, 2005.) 6 List of Bodywall Muscle Cells (for cell name/number correspondence see below and MusFig15A&B; cell numbering is according to Hedgecock et al., 1987 and differs from Wormbase) (PE=postembryonic)
> Dorsal Left Quadrant mu_bod (DL1) mu_bod (DL2) mu_bod (DL3) mu_bod (DL4) mu_bod (DL5) mu_bod (DL6) mu_bod (DL7) mu_bod (DL8) mu_bod (DL9) mu_bod (DL10) mu_bod (DL11) mu_bod (DL12) mu_bod (DL13) mu_bod (DL14) mu_bod (DL15) - PE mu_bod (DL16) - PE mu_bod (DL17) mu_bod (DL18) mu_bod (DL19) mu_bod (DL20) mu_bod (DL21) mu_bod (DL22) - PE mu_bod (DL23) mu_bod (DL24) | Ventral Left Quadrant mu_bod (VL1) mu_bod (VL2) mu_bod (VL3) mu_bod (VL4) mu_bod (VL5) mu_bod (VL6) mu_bod (VL7) mu_bod (VL8) mu_bod (VL9) mu_bod (VL10) mu_bod (VL11) mu_bod (VL12) mu_bod (VL13) mu_bod (VL14) mu_bod (VL15) mu_bod (VL16) mu_bod (VL17) - PE mu_bod (VL18) - PE mu_bod (VL19) mu_bod (VL20) - PE mu_bod (VL21) - PE mu_bod (VL22) mu_bod (VL23) | Ventral Right Quadrant mu_bod (VR1) mu_bod (VR2) mu_bod (VR3) mu_bod (VR4) mu_bod (VR5) mu_bod (VR6) mu_bod (VR7) mu_bod (VR8) mu_bod (VR9) mu_bod (VR10) mu_bod (VR11) mu_bod (VR12) mu_bod (VR13) mu_bod (VR14) mu_bod (VR15) mu_bod (VR16) mu_bod (VR17) - PE mu_bod (VR18) - PE mu_bod (VR19) mu_bod (VR20) mu_bod (VR21) mu_bod (VR22) - PE mu_bod (VR23) - PE mu_bod (VR24) | Dorsal Right Quadrant mu_bod (DR1) mu_bod (DR2) mu_bod (DR3) mu_bod (DR4) mu_bod (DR5) mu_bod (DR6) mu_bod (DR7) mu_bod (DR8) mu_bod (DR9) mu_bod (DR10) mu_bod (DR11) mu_bod (DR12) mu_bod (DR13) mu_bod (DR14) mu_bod (DR15) - PE mu_bod (DR16) - PE mu_bod (DR17) mu_bod (DR18) mu_bod (DR19) mu_bod (DR20) mu_bod (DR21) mu_bod (DR22) - PE mu_bod (DR23) mu_bod (DR24)
7 References Barstead, R.J. and Waterston, R.H. 1991. Vinculin is essential for muscle function in the nematode. J. Cell Biol. 114: 715-724. Article Bird, A.F. and Bird, J. 1991. The structure of nematodes. Academic Press, San Diego, CA. Burr, A.H.J. and Gans, C. 1998. Mechanical significance of obliquely striated architecture in nematode muscle. Biol. Bull. 194: 1-6. Article Coutu Hresko, M., Williams, B.D. and Waterston, R.H. 1994. Assembly of body wall muscle and muscle cell attachment structures in Caenorhabditis elegans. J. Cell Biol. 124: 491-506. Article Coutu Hresko, M., Schriefer, L.A., Shrimankar, P. and Waterston, R.H. 1999. Myotactin, a novel hypodermal protein involved in muscle-cell adhesion in Caenorhabditis elegans. J. Cell Biol. 146: 659-672. Article Cox, E.A. and Hardin, J. 2004. Sticky worms: adhesion complexes in C. elegans. J. Cell Sci. 117: 1885-1897. Article Ding, M., Woo, W.M. and Chisholm, A.D. 2004. The cytoskeleton and epidermal morphogenesis in C. elegans. Exp. Cell Res. 301: 84-90. Abstract Francis, G.R. and Waterston, R.H. 1985. Muscle organization in C. elegans: Localization of proteins implicated in thin filament attachment and I-band organization. J. Cell Biol. 101: 1532-1549. Article Francis, G.R. and Waterston, R.H. 1991. Muscle cell attachment in Caenorhabditis elegans. J. Cell Biol. 114: 465-479. Article Gatewood, B.K., and Bucher, E.A. 1997. The mup-4 locus in Caenorhabditis elegans is essential for hypodermal integrity, organismal morphogenesis and embryonic body wall muscle position. Genetics. 146: 165-183. Article Hahn, B.S. and Labouesse, M. 2001. Tissue integrity: Hemidesmosomes and resistance to stress. Curr. Biol. 11: R858-R861. Article Hedgecock, E.M., Culotti, J.G., Hall, D.H. and Stern, B.G. 1987. Genetics of cell and axon migrations in Caenorhabditis elegans. Development 100: 365‑382. Article Jorgensen, E.M. 2005. GABA. WormBook, ed. The C. elegans Research Community, WormBook, doi/10.1895/wormbook.1.14.1. Article Labouesse, M. 2006. Epithelial junctions and attachments. WormBook, ed. The C. elegans Research Community, WormBook, doi/10.1895/wormbook.1.56.1. Article Mclntire, S.L., Jorgensen, E. and Horvitz, H.R. 1993. Genes required for GABA function in Caenorhabditis elegans. Nature 364: 334-337. Abstract Moerman, D.G. and Fire, A. 1997. Muscle: Structure, Function, and Development. In C. elegans Volume II. Ed.s Riddle D.L., T Blumenthal, BJ Meyer and JR Priess. Pp 417-470. Cold Spring Harbor Laboratory Press. Article Moerman, D.G. and Williams, B.D. 2006. Sarcomere assembly in C. elegans muscle. WormBook, ed. The C. elegans Research Community, WormBook,doi/10.1895/wormbook.1.81.1. Article Moerman, D.G., Hutter, H., Mullen, G.P. and Schnabel, R. 1996. Cell autonomous expression of Perlecan and plasticity of cell shape in embryonic muscle of Caenorhabditis elegans. Dev. Biol. 173: 228 – 242. Article Plenefisch, J.D., Zhu, X. and Hedgecock, E.M. 2000. Fragile skeletal muscle attachments in dystrophic mutants of Caenorhabditis elegans: isolation and characterization of the mua genes. Development 127: 1197-1207. Article Richards, J.L, Zacharias, A.L., Walton, T., Burdick, J.T.. and Murray, J.I. 2013. A qualitative model of normal Caenorhabditis elegans embryogenesis and its disruption after stress. Dev. Biol.. 374: 12-23. Article Rogalski, T.M., Mullen, G.P., Bush, J.A., Gilchrist, E.J. and Moerman, D.G. 2001. UNC-52/perlecan isoform diversity and function in Caenorhabditis elegans. Biochem. Soc. Trans. 29: 171-176. Article Sulston, J.E. and Horvitz, H.R. 1977. Post-embryonic cell lineages of the nematode, Caenorhabditis elegans. Dev. Biol. 56: 110–156. Article Sulston, J.E., Schierenberg, E., White, J.G. and Thomson, J.N. 1983. The embryonic cell lineage of the nematode Caenorhabditis elegans. Dev. Biol. 100: 64-119. Article Waterston, R.H. 1988. Muscle. In "The nematode C. elegans" (W. B. Wood ed.) pp281-335. Cold Spring Harbor Laboratory Press, New York. Abstract White, J.G., Southgate, E., Thomson, J.N. and Brenner, S. 1986. The structure of the nervous system of the nematode Caenorhabditis elegans. Phil. Trans. Roy. Soc. Lond. 314B: 1-340. Article White, J. 1988. The Anatomy. In The nematode C. elegans (ed. W.B. Wood). Chapter 4. pp 81-122. Cold Spring Harbor Laboratory Press, Cold Spring Harbor, New York. Abstract Williams, B.D. and Waterston, R.H. 1994. Genes critical for muscle development and function in Caenorhabditis elegans identified through lethal mutations. J. Cell Biol. 124: 475-490. Article Woo, W.M., Goncharov, A., Jin, Y. and Chisholm, A.D. 2004. Intermediate filaments are required for C. elegans epidermal elongation. Dev. Biol. 267: 216-229. Article Zengel, J.M. and Epstein H.F. 1980. Muscle development in Caenorhabditis elegans: a molecular genetic approach. In "Nematodes as Biological Models" Volume 1. (ed.) Zuckerman B.M. pp 73-126. Academic Press, New York. Abstract
This chapter should be cited as: Altun, Z.F. and Hall, D.H. 2009. Muscle system, somatic muscle. In WormAtlas. doi:10.3908/wormatlas.1.7 Edited for the web by Laura A. Herndon. Last revision: May 31, 2013.

©Copyright 2025 WormAtlas (Cold Spring Harbor Laboratory Press) All Rights Reserved |